@@ -300,6 +300,132 @@ def menus(context, _get_config=None):
     return '<script type="text/javascript">var menus={}</script>'.format(menus_string)
 
 
+@register.simple_tag(takes_context=True)
+def admin_menus(context, _get_config=None):
+    data = []
+
+    # return request.user.has_perm("%s.%s" % (opts.app_label, codename))
+    if not _get_config:
+        _get_config = get_config
+
+    config = _get_config('SIMPLEUI_CONFIG')
+    if not config:
+        config = {}
+
+    if config.get('dynamic', False) is True:
+        config = _import_reload(_get_config('DJANGO_SETTINGS_MODULE')).SIMPLEUI_CONFIG
+
+    config = copy.deepcopy(config)
+
+    # 获取django所有app的models
+    app_list = context.get('app_list')
+    for app in app_list:
+        _models = [
+            {
+                'name': m.get('name'),
+                'icon': get_icon(m.get('object_name'), unicode_to_str(m.get('name'))),
+                'url': m.get('admin_url'),
+                'addUrl': m.get('add_url'),
+                'breadcrumbs': [{
+                    'name': app.get('name'),
+                    'icon': get_icon(app.get('app_label'), app.get('name'))
+                }, {
+                    'name': m.get('name'),
+                    'icon': get_icon(m.get('object_name'), unicode_to_str(m.get('name')))
+                }]
+            }
+
+            for m in app.get('models')
+        ] if app.get('models') else []
+
+        module = {
+            'name': app.get('name'),
+            'icon': get_icon(app.get('app_label'), app.get('name')),
+            'models': _models
+        }
+        data.append(module)
+
+    # 如果有配置自定义menu就读取自定义的，没有就调用系统的
+    if config and 'menus' in config:
+        # 如果'system_keep'!=True，则清空系统的菜单
+        if not config.get('system_keep', None):
+            data = []
+
+        # 读取自定义菜单
+        temp = config.get('menus')
+        # 如果是超级管理员则拥有所有菜单
+        if context.request.user.is_superuser:
+            for i in temp:
+                data.append(i)
+
+        # 根据权限配置删除菜单
+        else:
+            # 获取权限列表
+            groups_permissions = context.request.user.get_group_permissions()
+            for i in temp:
+                # 检查1级菜单
+                if 'codename' not in i \
+                        or (True in [(True if i['codename'] in g_p else False)
+                                     for g_p in groups_permissions]) == False:
+                    if not context.request.user.is_superuser:
+                        continue
+                # 处理面包屑
+                if 'models' in i:
+                    delete_models = list()
+                    for k in i.get('models'):
+                        # check level 2 menu
+                        if 'codename' not in i \
+                            or 'codename' not in k \
+                            or (i['codename']+'.'+(k['codename']) not in groups_permissions \
+                                and i['codename']+'.view_'+(k['codename']) not in groups_permissions \
+                                and i['codename']+'.add_'+(k['codename']) not in groups_permissions \
+                                and i['codename']+'.change_'+(k['codename']) not in groups_permissions \
+                                and i['codename']+'.delete_'+(k['codename']) not in groups_permissions \
+                                and k['codename'] not in groups_permissions):
+                            if not context.request.user.is_superuser:
+                                delete_models.append(k)
+                                continue
+                        k['breadcrumbs'] = [{
+                            'name': i.get('name'),
+                            'icon': i.get('icon')
+                        }, {
+                            'name': k.get('name'),
+                            'icon': k.get('icon')
+                        }]
+                    for del_m in delete_models:
+                        i['models'].remove(del_m)
+                else:
+                    i['breadcrumbs'] = [{
+                        'name': i.get('name'),
+                        'icon': i.get('icon')
+                    }]
+                data.append(i)
+    else:
+        data = config.get('menus')
+
+    # 获取侧边栏排序, 如果设置了就按照设置的内容排序, 留空则表示默认排序以及全部显示
+    if config.get('admin_menu_display') is not None:
+        display_data = list()
+        for _app in data:
+            if _app['name'] not in config.get('admin_menu_display'):
+                continue
+            _app['_weight'] = config.get('admin_menu_display').index(_app['name'])
+            display_data.append(_app)
+        display_data.sort(key=lambda x: x['_weight'])
+        data = display_data
+
+    # 给每个菜单增加一个唯一标识，用于tab页判断
+    eid = 1000
+    handler_eid(data, eid)
+    menus_string = json.dumps(data, cls=LazyEncoder)
+
+    # 把data放入session中，其他地方可以调用
+    if not isinstance(context, dict) and context.request:
+        context.request.session['_menus'] = menus_string
+
+    return '<script type="text/javascript">var menus={}</script>'.format(menus_string)
+
+
 def handler_eid(data, eid):
     for i in data:
         eid += 1
